api

package module
v0.0.0-...-c86bf35 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	ProjectService_Init_FullMethodName    = "/temporal.omes.projects.v1.ProjectService/Init"
	ProjectService_Execute_FullMethodName = "/temporal.omes.projects.v1.ProjectService/Execute"
)

Variables

var File_harness_api_api_proto protoreflect.FileDescriptor
var ProjectService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "temporal.omes.projects.v1.ProjectService",
	HandlerType: (*ProjectServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Init",
			Handler:    _ProjectService_Init_Handler,
		},
		{
			MethodName: "Execute",
			Handler:    _ProjectService_Execute_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "harness/api/api.proto",
}

ProjectService_ServiceDesc is the grpc.ServiceDesc for ProjectService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterProjectServiceServer

func RegisterProjectServiceServer(s grpc.ServiceRegistrar, srv ProjectServiceServer)

Types

type ConnectOptions

type ConnectOptions struct {
	Namespace               string `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
	ServerAddress           string `protobuf:"bytes,2,opt,name=server_address,json=serverAddress,proto3" json:"server_address,omitempty"`
	AuthHeader              string `protobuf:"bytes,3,opt,name=auth_header,json=authHeader,proto3" json:"auth_header,omitempty"`
	EnableTls               bool   `protobuf:"varint,4,opt,name=enable_tls,json=enableTls,proto3" json:"enable_tls,omitempty"`
	TlsCertPath             string `protobuf:"bytes,5,opt,name=tls_cert_path,json=tlsCertPath,proto3" json:"tls_cert_path,omitempty"`
	TlsKeyPath              string `protobuf:"bytes,6,opt,name=tls_key_path,json=tlsKeyPath,proto3" json:"tls_key_path,omitempty"`
	TlsServerName           string `protobuf:"bytes,7,opt,name=tls_server_name,json=tlsServerName,proto3" json:"tls_server_name,omitempty"`
	DisableHostVerification bool   `` /* 133-byte string literal not displayed */
	// contains filtered or unexported fields
}

Connection options passed from the CLI to the project-server during Init. These fields intentionally mirror the supported Omes client options used for connecting workers and scenarios today.

func (*ConnectOptions) Descriptor deprecated

func (*ConnectOptions) Descriptor() ([]byte, []int)

Deprecated: Use ConnectOptions.ProtoReflect.Descriptor instead.

func (*ConnectOptions) GetAuthHeader

func (x *ConnectOptions) GetAuthHeader() string

func (*ConnectOptions) GetDisableHostVerification

func (x *ConnectOptions) GetDisableHostVerification() bool

func (*ConnectOptions) GetEnableTls

func (x *ConnectOptions) GetEnableTls() bool

func (*ConnectOptions) GetNamespace

func (x *ConnectOptions) GetNamespace() string

func (*ConnectOptions) GetServerAddress

func (x *ConnectOptions) GetServerAddress() string

func (*ConnectOptions) GetTlsCertPath

func (x *ConnectOptions) GetTlsCertPath() string

func (*ConnectOptions) GetTlsKeyPath

func (x *ConnectOptions) GetTlsKeyPath() string

func (*ConnectOptions) GetTlsServerName

func (x *ConnectOptions) GetTlsServerName() string

func (*ConnectOptions) ProtoMessage

func (*ConnectOptions) ProtoMessage()

func (*ConnectOptions) ProtoReflect

func (x *ConnectOptions) ProtoReflect() protoreflect.Message

func (*ConnectOptions) Reset

func (x *ConnectOptions) Reset()

func (*ConnectOptions) String

func (x *ConnectOptions) String() string

type ExecuteRequest

type ExecuteRequest struct {
	Iteration int64  `protobuf:"varint,1,opt,name=iteration,proto3" json:"iteration,omitempty"`
	TaskQueue string `protobuf:"bytes,2,opt,name=task_queue,json=taskQueue,proto3" json:"task_queue,omitempty"`
	// Reserved for future executor-specific per-iteration data.
	Payload []byte `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
	// contains filtered or unexported fields
}

Sent once per iteration. The project-server starts workflows and verifies results within the Execute handler.

func (*ExecuteRequest) Descriptor deprecated

func (*ExecuteRequest) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteRequest.ProtoReflect.Descriptor instead.

func (*ExecuteRequest) GetIteration

func (x *ExecuteRequest) GetIteration() int64

func (*ExecuteRequest) GetPayload

func (x *ExecuteRequest) GetPayload() []byte

func (*ExecuteRequest) GetTaskQueue

func (x *ExecuteRequest) GetTaskQueue() string

func (*ExecuteRequest) ProtoMessage

func (*ExecuteRequest) ProtoMessage()

func (*ExecuteRequest) ProtoReflect

func (x *ExecuteRequest) ProtoReflect() protoreflect.Message

func (*ExecuteRequest) Reset

func (x *ExecuteRequest) Reset()

func (*ExecuteRequest) String

func (x *ExecuteRequest) String() string

type ExecuteResponse

type ExecuteResponse struct {
	// contains filtered or unexported fields
}

func (*ExecuteResponse) Descriptor deprecated

func (*ExecuteResponse) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteResponse.ProtoReflect.Descriptor instead.

func (*ExecuteResponse) ProtoMessage

func (*ExecuteResponse) ProtoMessage()

func (*ExecuteResponse) ProtoReflect

func (x *ExecuteResponse) ProtoReflect() protoreflect.Message

func (*ExecuteResponse) Reset

func (x *ExecuteResponse) Reset()

func (*ExecuteResponse) String

func (x *ExecuteResponse) String() string

type InitRequest

type InitRequest struct {
	ExecutionId    string          `protobuf:"bytes,1,opt,name=execution_id,json=executionId,proto3" json:"execution_id,omitempty"`
	RunId          string          `protobuf:"bytes,2,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
	TaskQueue      string          `protobuf:"bytes,3,opt,name=task_queue,json=taskQueue,proto3" json:"task_queue,omitempty"`
	ConnectOptions *ConnectOptions `protobuf:"bytes,4,opt,name=connect_options,json=connectOptions,proto3" json:"connect_options,omitempty"`
	// Optional JSON project configuration, passed from --option project-config-file
	// to the project's OnInit callback. Schema is project-defined.
	ConfigJson []byte `protobuf:"bytes,5,opt,name=config_json,json=configJson,proto3" json:"config_json,omitempty"`
	// contains filtered or unexported fields
}

Sent once at the start of a test run to initialize the project-server.

func (*InitRequest) Descriptor deprecated

func (*InitRequest) Descriptor() ([]byte, []int)

Deprecated: Use InitRequest.ProtoReflect.Descriptor instead.

func (*InitRequest) GetConfigJson

func (x *InitRequest) GetConfigJson() []byte

func (*InitRequest) GetConnectOptions

func (x *InitRequest) GetConnectOptions() *ConnectOptions

func (*InitRequest) GetExecutionId

func (x *InitRequest) GetExecutionId() string

func (*InitRequest) GetRunId

func (x *InitRequest) GetRunId() string

func (*InitRequest) GetTaskQueue

func (x *InitRequest) GetTaskQueue() string

func (*InitRequest) ProtoMessage

func (*InitRequest) ProtoMessage()

func (*InitRequest) ProtoReflect

func (x *InitRequest) ProtoReflect() protoreflect.Message

func (*InitRequest) Reset

func (x *InitRequest) Reset()

func (*InitRequest) String

func (x *InitRequest) String() string

type InitResponse

type InitResponse struct {
	// contains filtered or unexported fields
}

func (*InitResponse) Descriptor deprecated

func (*InitResponse) Descriptor() ([]byte, []int)

Deprecated: Use InitResponse.ProtoReflect.Descriptor instead.

func (*InitResponse) ProtoMessage

func (*InitResponse) ProtoMessage()

func (*InitResponse) ProtoReflect

func (x *InitResponse) ProtoReflect() protoreflect.Message

func (*InitResponse) Reset

func (x *InitResponse) Reset()

func (*InitResponse) String

func (x *InitResponse) String() string

type ProjectServiceClient

type ProjectServiceClient interface {
	// Init creates a Temporal client, runs project-specific setup, and prepares for execution.
	Init(ctx context.Context, in *InitRequest, opts ...grpc.CallOption) (*InitResponse, error)
	// Execute runs a single test iteration (e.g., start a workflow and verify the result).
	Execute(ctx context.Context, in *ExecuteRequest, opts ...grpc.CallOption) (*ExecuteResponse, error)
}

ProjectServiceClient is the client API for ProjectService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

ProjectService is the gRPC interface used by omes to intialize and drive load to a project.

type ProjectServiceServer

type ProjectServiceServer interface {
	// Init creates a Temporal client, runs project-specific setup, and prepares for execution.
	Init(context.Context, *InitRequest) (*InitResponse, error)
	// Execute runs a single test iteration (e.g., start a workflow and verify the result).
	Execute(context.Context, *ExecuteRequest) (*ExecuteResponse, error)
	// contains filtered or unexported methods
}

ProjectServiceServer is the server API for ProjectService service. All implementations must embed UnimplementedProjectServiceServer for forward compatibility.

ProjectService is the gRPC interface used by omes to intialize and drive load to a project.

type UnimplementedProjectServiceServer

type UnimplementedProjectServiceServer struct{}

UnimplementedProjectServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedProjectServiceServer) Execute

func (UnimplementedProjectServiceServer) Init

type UnsafeProjectServiceServer

type UnsafeProjectServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeProjectServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ProjectServiceServer will result in compilation errors.

Jump to